# AWS MFA Credentials Updater

> A convinient way to update AWS credentials for an AWS profile with MFA enforced.

## Installation

Using `pip`

```sh
pip install aws_credentialer
```

## Usage Example

Run the following command in your favorite terminal:

```sh
python -m aws_credentialer nnnnnn
```

Help is available with the `-h` parameter.

## Release History

* 0.1.0
  * The first proper release.
